Debian User Forums • Index page

# Debian User Forums

Skip to content

Advanced search

It is currently 2014-12-06 00:55

- View unanswered posts • View active topics

- Forum
    Topics
    Posts
    Last post

- News & Announcements
  News and announcements regarding Debian and the forum. Not for support questions.
    37 Topics
    399 Posts
    Last post by craigevil
    2014-08-31 05:46

- Help
    Topics
    Posts
    Last post

- Installation
  Help with issues regarding installation of Debian
    8602 Topics
    55830 Posts
    Last post by kpg993
    2014-12-06 00:46
- Beginners Questions
  New to Debian (Or Linux in general)? Ask your questions here!
    5463 Topics
    37570 Posts
    Last post by EdJones
    2014-12-06 00:23
- General Questions
  If none of the more specific forums is the right place to ask
    16960 Topics
    103143 Posts
    Last post by ricanlinux
    2014-12-05 20:19
- Desktop & Multimedia
  Everything about X, Gnome, KDE, ... and everything running on it
    11221 Topics
    66166 Posts
    Last post by stevepusser
    2014-12-05 20:38
- System configuration
  Kernels & Hardware, configuring network, installing services
    16304 Topics
    79800 Posts
    Last post by zoltix
    2014-12-05 23:57
- Hardware
  Getting your soundcard to work, using Debian on non-i386 hardware, etc
    6624 Topics
    33576 Posts
    Last post by debianpwr
    2014-12-05 09:39
- Programming
  Need help with C, C++, perl, python, etc?
    2045 Topics
    10892 Posts
    Last post by stevepusser
    2014-12-05 20:54

- Documentation
    Topics
    Posts
    Last post

- Docs, Howtos, Tips & Tricks
  Share your own howto's etc. Not for support questions!
    1000 Topics
    9178 Posts
    Last post by josephg
    2014-12-05 12:59

- Discussion
    Topics
    Posts
    Last post

- General Discussion
  Here you can discuss every aspect of Debian. Note: not for support requests!
    2863 Topics
    45225 Posts
    Last post by skaendo
    2014-12-06 00:34
- Debian Development
  News and discussion about development of the Debian OS itself
    522 Topics
    4741 Posts
    Last post by Crewp
    2014-11-30 22:33
- Forum stuff & feedback
  Have something to say about forums.debian.net itself?
    449 Topics
    5515 Posts
    Last post by scientific
    2014-11-28 23:04
- Offtopic
  If it doesn't relate to Debian, but you still want to share it, please do it here
    3208 Topics
    51775 Posts
    Last post by n_hologram
    2014-12-05 21:22

### Login • Register

Username: Password: | Log me on automatically each visit

### Who is online

In total there are 67 users online :: 5 registered, 4 hidden and 58 guests (based on users active over the past 5 minutes)
Most users ever online was 810 on 2012-02-06 05:07
Registered users: Alexa [Bot], Bing [Bot], LurNer, marchello, stevesr0
Legend: Administrators, Global moderators, Server Admins, Spam Hunters

### Statistics

Total posts 505134 • Total topics 75397 • Total members 35040 • Our newest member Malice

fashionable